Place Name - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Place Name

A `betty.model.ancestry.PlaceName` describes a name for a place.

## Fields

Names inherit from:

- Privacy

`date` (Datey)

  When this name was used.

`id` (`str`)

  The name’s own entity ID.

`locale` (optional `str`)

  The name’s locale as an IETF BCP 47 language tag.

`name` (`str`)

  The human-readable name.

`place` (Place)

  The place whose name this is.